# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class ModeFileExtensionFilterEnum(object):

    """Implementation of the 'ModeFileExtensionFilter' enum.
    The mode applied to the list of file extensions 'kWhitelist' indicates a
    allowlist extension filter. 'kBlacklist' indicates a denylist extension
    filter.


    Attributes:
        KWHITELIST: TODO: type description here.
        KBLACKLIST: TODO: type description here.

    """

    KWHITELIST = 'kWhitelist'

    KBLACKLIST = 'kBlacklist'
